diff src/conversation.h @ 10824:8d52201620d0

[gaim-migrate @ 12488] This changes gaim_conv_window_remove_conversation to take a GaimConversion pointer to remore instead of an index. Every place just called a function to get the index before calling it anyway. This may or may not help the contact aware convo bugs, I didn't test it yet, but I believe it to be a step in the right direction. committer: Tailor Script <tailor@pidgin.im>
author Tim Ringenbach <marv@pidgin.im>
date Fri, 15 Apr 2005 00:28:54 +0000
parents 4151d16f6348
children 53e7884c549a
line wrap: on
line diff
--- a/src/conversation.h	Thu Apr 14 04:08:10 2005 +0000
+++ b/src/conversation.h	Fri Apr 15 00:28:54 2005 +0000
@@ -402,17 +402,15 @@
 									  GaimConversation *conv);
 
 /**
- * Removes the conversation at the specified index from the window.
- *
- * If there is no conversation at this index, this will do nothing.
+ * Removes the conversation from the window.
  *
  * @param win   The window.
  * @param index The index of the conversation.
  *
  * @return The conversation removed.
  */
 GaimConversation *gaim_conv_window_remove_conversation(GaimConvWindow *win,
-													   unsigned int index);
+                                                       GaimConversation *conv);
 
 /**
  * Moves the conversation at the specified index in a window to a new index.
@@ -402,17 +402,15 @@
  *
  * @param win   The window.
- * @param index The index of the conversation.
+ * @param conv The conversation.
  *
  * @return The conversation removed.